function  MBKS_zobraz_obsadenosti_zmien(n, m, z, D, XOPT)
% Funkcia, ktora sluzi na zostavenie grafu, ktory zobrazuje pocet sestier
% na jednotlivych smenach v jednotlive dni
% Volanie
%   MBKS_zostav_zobrazenie2(n, m, z, D, XOPT)
% Vstup:
%   n - pocet sestier
%   m - pocet dni planovaneho obdobia
%   z - pocet smien
%   D - minimalny predpisany pocet sestier na smenach
%   XOPT - riesenie v tvare viacrozmernej matice
% Výstup:
%   Graf poctov sestier na rannej zmene za jednotlive dni
%   Graf poctov sestier na poobednej zmene za jednotlive dni
%   Graf poctov sestier na nocnej zmene za jednotlive dni
%% ABOUT
% Zobrazenie poctu sestier na smenach v jednotlivych dnoch sa vytvara pomocou
% funkcie bar a zobrazenie minimalneho poctu sestier na smenach (matica D zo zadiania)
% sa vytvara pomocou funkcie plot. K zobrazeniu poctu sestier na smenach je
% potrebne vytvorit maticu POCTY_SESTIER. Tato matica pre kazdu smenu k a
% kazdy den j (t.j. POCTY_SESTIER(k,j)) obsahuje hodnotu, ktora sa ziska
% scitanim XOPT(i,j,k) cez vsetky i. V cykle cez smeny sa vsetko vykresluje 
% do jedneho okna a pomocou funkcie bar sa zobrazuje k-ty riadok matice
% POCTY_SESTIER

%% Deklaracia a populacia matice poctu sestier
POCTY_SESTIER = zeros(z,m); % Inicializacia matice 

for k = 1:z
    for j = 1:m
        for i = 1:n
            POCTY_SESTIER(k,j) = sum(XOPT(:,j,k)); % naplnenie matice 
        end
    end
end

%% Vykreslenie poctu sestier na smenach
for i = 1:z
    subplot(z,1,i);
    bar(POCTY_SESTIER(i,:)) % Skutocny pocet sestier na smene k
    hold on;
    plot(D(:,i),'r.-','linewidth',3,'markersize',30) % Pozadovany pocet sestier
    hold off;
    grid off;
    title(sprintf('Počty sestier na smene číslo %d ', i),'FontSize',16);
    legend({'Skutočný počet','Pozadovany pocet'},'Location','northeastoutside');
    xlabel('Deň','fontsize',12);
    ylabel('Počty sestier','fontsize',12);
end

end